@@ -36,6 +36,7 @@ import net.sf.ehcache.cluster.ClusterNode;
 import net.sf.ehcache.cluster.ClusterScheme;
 import net.sf.ehcache.cluster.ClusterTopologyListener;
 
+import org.junit.Assert;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.mockito.runners.MockitoJUnitRunner;
@@ -53,17 +54,12 @@ public class RejoinEventSequenceTest extends TestCase {
         final ClusteredInstanceFactory mockFactory = mock(ClusteredInstanceFactory.class);
         final MockCacheCluster mockCacheCluster = new MockCacheCluster();
         final CyclicBarrier barrier = new CyclicBarrier(2);
+        final AtomicBoolean firstTime = new AtomicBoolean(true);
         TerracottaUnitTesting.setupTerracottaTesting(mockFactory, new Runnable() {
-            AtomicBoolean firstTime = new AtomicBoolean(true);
             public void run() {
-                if(!firstTime.getAndSet(false) && nodeLeftFired.get()) {
-                    try {
-                        barrier.await();
-                    } catch (InterruptedException e) {
-                        e.printStackTrace();
-                    } catch (BrokenBarrierException e) {
-                        e.printStackTrace();
-                    }
+                if(!firstTime.getAndSet(false)) {
+                    info("hitting barrier in Runnable()");
+                    await(barrier);
                 }
                 mockCacheCluster.removeAllListeners();
             }
@@ -81,6 +77,7 @@ public class RejoinEventSequenceTest extends TestCase {
             n++;
             nodeLeftFired.set(false);
             info("================================= Run: " + n + " =========================================================");
+            Assert.assertFalse("firstTime should be false", firstTime.get());
             info("Sleeping for 5 secs...");
             Thread.sleep(5000);
             info("firing node left...");
@@ -99,9 +96,6 @@ public class RejoinEventSequenceTest extends TestCase {
 
             info("Clearing events");
             listener.clearEvents();
-            if(nodeLeftFired.get()) {
-                barrier.reset();
-            }
         }
     }
 
@@ -109,6 +103,16 @@ public class RejoinEventSequenceTest extends TestCase {
         LOG.info("____ " + string);
     }
 
+    private static void await(CyclicBarrier barrier) {
+        try {
+            barrier.await();
+        } catch (InterruptedException e) {
+            LOG.error("InterruptedException while waiting on barrier ", e);
+        } catch (BrokenBarrierException e) {
+            LOG.error("BrokenBarrierException while waiting on barrier ", e);
+        }
+    }
+
     private static final class RecordingListener implements ClusterTopologyListener {
         private final List<Event> events = new ArrayList<Event>();
         private volatile EventType state;
@@ -135,13 +139,8 @@ public class RejoinEventSequenceTest extends TestCase {
             state = EventType.LEFT;
             notifyAll();
             nodeLeftFired.set(true);
-            try {
-                barrier.await();
-            } catch (InterruptedException e) {
-                e.printStackTrace();
-            } catch (BrokenBarrierException e) {
-                e.printStackTrace();
-            }
+            info("hitting barrier in nodeLeft()");
+            await(barrier);
         }
 
         public synchronized void clusterOnline(ClusterNode node) {
